@@ -2,9 +2,12 @@
 #
 """
 I/O for the OFF surface format, cf.
-<https://en.wikipedia.org/wiki/OFF_(file_format)>.
+<https://en.wikipedia.org/wiki/OFF_(file_format)>,
+<http://www.geomview.org/docs/html/OFF.html>.
 """
 from itertools import islice
+import logging
+
 import numpy
 
 from .mesh import Mesh
@@ -77,7 +80,9 @@ def read_buffer(f):
 
         data = stripped.split()
         num_points = int(data[0])
-        assert num_points == len(data) - 1
+        # Don't be too strict with the len(data) assertions here; the OFF specifications
+        # allows for RGB colors.
+        # assert num_points == len(data) - 1
         assert num_points == 3, "Can only handle triangular faces"
 
         data = [int(data[1]), int(data[2]), int(data[3])]
@@ -91,6 +96,15 @@ def read_buffer(f):
 
 
 def write(filename, mesh):
+    if mesh.points.shape[1] == 2:
+        logging.warning(
+            "OFF requires 3D points, but 2D points given. "
+            "Appending 0 third component."
+        )
+        mesh.points = numpy.column_stack(
+            [mesh.points[:, 0], mesh.points[:, 1], numpy.zeros(mesh.points.shape[0])]
+        )
+
     for key in mesh.cells:
         assert key in ["triangle"], "Can only deal with triangular faces"
 
