@@ -8,6 +8,7 @@ import numpy
 
 from .__about__ import __version__
 from .mesh import Mesh
+from .common import raw_from_cell_data
 
 
 # https://www.vtk.org/doc/nightly/html/vtkCellType_8h_source.html
@@ -124,7 +125,7 @@ def read_buffer(f):
     f.readline()
     f.readline()
 
-    data_type = f.readline().decode("utf-8").strip()
+    data_type = f.readline().decode("utf-8").strip().upper()
     assert data_type in ["ASCII", "BINARY"], "Unknown VTK data type '{}'.".format(
         data_type
     )
@@ -151,20 +152,18 @@ def read_buffer(f):
             continue
 
         split = line.split()
-        section = split[0]
+        section = split[0].upper()
 
         if section == "DATASET":
-            dataset_type = split[1]
+            dataset_type = split[1].upper()
             assert (
                 dataset_type == "UNSTRUCTURED_GRID"
-            ), "Only VTK UNSTRUCTURED_GRID supported (not {}).".format(
-                dataset_type
-            )
+            ), "Only VTK UNSTRUCTURED_GRID supported (not {}).".format(dataset_type)
 
         elif section == "POINTS":
             active = "POINTS"
             num_points = int(split[1])
-            data_type = split[2]
+            data_type = split[2].lower()
             points = _read_points(f, data_type, is_ascii, num_points)
 
         elif section == "CELLS":
@@ -185,6 +184,11 @@ def read_buffer(f):
             active = "CELL_DATA"
             num_items = int(split[1])
 
+        elif section == "LOOKUP_TABLE":
+            num_items = int(split[2])
+            data = numpy.fromfile(f, count=num_items * 4, sep=" ", dtype=float)
+            rgba = data.reshape((num_items, 4))  # noqa F841
+
         elif section == "SCALARS":
             if active == "POINT_DATA":
                 d = point_data
@@ -281,7 +285,7 @@ def _read_cell_types(f, is_ascii, num_items):
 
 def _read_scalar_field(f, num_data, split):
     data_name = split[1]
-    data_type = split[2]
+    data_type = split[2].lower()
     try:
         num_comp = int(split[3])
     except IndexError:
@@ -293,7 +297,7 @@ def _read_scalar_field(f, num_data, split):
 
     dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
     lt, _ = f.readline().decode("utf-8").split()
-    assert lt == "LOOKUP_TABLE"
+    assert lt.upper() == "LOOKUP_TABLE"
     data = numpy.fromfile(f, count=num_data, sep=" ", dtype=dtype)
 
     return {data_name: data}
@@ -311,7 +315,7 @@ def _read_vector_field(f, num_data, split):
 
 def _read_tensor_field(f, num_data, split):
     data_name = split[1]
-    data_type = split[2]
+    data_type = split[2].lower()
 
     dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
     data = numpy.fromfile(f, count=9 * num_data, sep=" ", dtype=dtype).reshape(-1, 3, 3)
@@ -325,7 +329,7 @@ def _read_fields(f, num_fields, is_ascii):
         name, shape0, shape1, data_type = f.readline().decode("utf-8").split()
         shape0 = int(shape0)
         shape1 = int(shape1)
-        dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
+        dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type.lower()])
 
         if is_ascii:
             dat = numpy.fromfile(f, count=shape0 * shape1, sep=" ", dtype=dtype)
@@ -345,21 +349,6 @@ def _read_fields(f, num_fields, is_ascii):
     return data
 
 
-def raw_from_cell_data(cell_data):
-    # merge cell data
-    cell_data_raw = {}
-    for d in cell_data.values():
-        for name, values in d.items():
-            if name in cell_data_raw:
-                cell_data_raw[name].append(values)
-            else:
-                cell_data_raw[name] = [values]
-    for name in cell_data_raw:
-        cell_data_raw[name] = numpy.concatenate(cell_data_raw[name])
-
-    return cell_data_raw
-
-
 def translate_cells(data, types, cell_data_raw):
     # https://www.vtk.org/doc/nightly/html/vtkCellType_8h_source.html
     # Translate it into the cells dictionary.
@@ -394,9 +383,14 @@ def translate_cells(data, types, cell_data_raw):
 
 
 def write(filename, mesh, write_binary=True):
-    assert (
-        mesh.points.shape[1] == 3
-    ), "VTK point coordinates must be 3D (shape: {})".format(mesh.points.shape)
+    if mesh.points.shape[1] == 2:
+        logging.warning(
+            "VTK requires 3D points, but 2D points given. "
+            "Appending 0 third component."
+        )
+        mesh.points = numpy.column_stack(
+            [mesh.points[:, 0], mesh.points[:, 1], numpy.zeros(mesh.points.shape[0])]
+        )
 
     if not write_binary:
         logging.warning("VTK ASCII files are only meant for debugging.")
@@ -503,6 +497,15 @@ def _write_field_data(f, data, write_binary):
             ), "Only one and two-dimensional field data supported."
             num_tuples = values.shape[0]
             num_components = values.shape[1]
+
+        if " " in name:
+            logging.warning(
+                "VTK doesn't support spaces in field names. " 'Renaming "%s" to "%s".',
+                name,
+                name.replace(" ", "_"),
+            )
+            name = name.replace(" ", "_")
+
         f.write(
             (
                 "{} {} {} {}\n".format(
