@@ -12,6 +12,11 @@ import meshio
 # In general:
 # Use values with an infinite decimal representation to test precision.
 
+tri_mesh_2d = meshio.Mesh(
+    numpy.array([[0.0, 0.0], [1.0, 0.0], [1.0, 1.0], [0.0, 1.0]]) / 3,
+    {"triangle": numpy.array([[0, 1, 2], [0, 2, 3]])},
+)
+
 tri_mesh = meshio.Mesh(
     numpy.array([[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0], [0.0, 1.0, 0.0]])
     / 3,
