@@ -9,7 +9,14 @@ import helpers
 
 @pytest.mark.parametrize(
     "mesh",
-    [helpers.tri_mesh, helpers.quad_mesh, helpers.tri_quad_mesh, helpers.tet_mesh],
+    [
+        helpers.tri_mesh,
+        helpers.tri_mesh_2d,
+        helpers.quad_mesh,
+        helpers.tri_quad_mesh,
+        helpers.tet_mesh,
+        helpers.hex_mesh,
+    ],
 )
 def test_io(mesh):
     helpers.write_read(meshio.medit_io.write, meshio.medit_io.read, mesh, 1.0e-15)
